1.  Lipsum

    *   Ichi
    *   Ni
    *   San

2.  {panel type="teacher-note" subtitle="true"}

    # Teacher Note

    ## Curriculum guides for Algorithms

    This text is the panel's contents.

    {panel end}

3.  Ipsem
